==> nextcloud-28.0.3.tgz: nextcloud/apps/logreader/l10n/en_GB.js <==
OC.L10N.register(
    "logreader",
    {
    "Logging" : "Logging",
    "Errors in the log" : "Errors in the log",
    "No errors in the logs since %s" : "No errors in the logs since %s",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["%n error in the logs since %s","%n errors in the logs since %s"],
    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["%n warning in the logs since %s","%n warnings in the logs since %s"],
    "Log Reader" : "Log Reader",
    "A log reader for Nextcloud" : "A log reader for Nextcloud",
    "Log reader for Nextcloud" : "Log reader for Nextcloud",
    "Log reader" : "Log reader",
    "Open log reader settings" : "Open log reader settings",
    "Log reader settings" : "Log reader settings",
    "Currently the log file {file} is shown" : "Currently the log file {file} is shown",
    "Show server log" : "Show server log",
    "Live view is disabled" : "Live view is disabled",
    "No log file" : "No log file",
    "File-based logging must be enabled to access logs from the Web UI." : "File-based logging must be enabled to access logs from the Web UI.",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual.",
    "Level" : "Level",
    "App" : "App",
    "No app in context" : "No app in context",
    "Time" : "Time",
    "Copy raw entry" : "Copy raw entry",
    "Copy formatted entry" : "Copy formatted entry",
    "Hide exception details" : "Hide exception details",
    "View exception details" : "View exception details",
    "Raw log entry" : "Raw log entry",
    "Log entry successfully copied" : "Log entry successfully copied",
    "Search log entries" : "Search log entries",
    "Caused by {exception}" : "Caused by {exception}",
    "Line {line}" : "Line {line}",
    "Filter log levels" : "Filter log levels",
    "Set log level" : "Set log level",
    "Time format" : "Time format",
    "Live view" : "Live view",
    "Download/Upload logs" : "Download/Upload logs",
    "You can also show log entries copied from your clipboard by pasting them on the log view using: {keyboardShortcut}" : "You can also show log entries copied from your clipboard by pasting them on the log view using: {keyboardShortcut}",
    "Download logs" : "Download logs",
    "Show local log file" : "Show local log file",
    "Upload local log file to be displayed" : "Upload local log file to be displayed",
    "Ctrl" : "Ctrl",
    "Could not parse local log file" : "Could not parse local log file",
    "Raw data" : "Raw data",
    "Local time" : "Local time",
    "UTC time" : "UTC time",
    "Time format used for displaying the timestamp" : "Time format used for displaying the timestamp",
    "(Local log files only support the \"raw\" time format)" : "(Local log files only support the \"raw\" time format)",
    "Could not change date time format." : "Could not change date time format.",
    "Polling is disabled because server is not configured to log to file" : "Polling is disabled because server is not configured to log to file",
    "Polling (live view)" : "Polling (live view)",
    "Could not change live view setting." : "Could not change live view setting.",
    "Filter logging levels" : "Filter logging levels",
    "Could not set logging levels to show" : "Could not set logging levels to show",
    "Set backend loglevel" : "Set backend loglevel",
    "Could not set logging level" : "Could not set logging level",
    "Application" : "Application",
    "Message" : "Message",
    "Log entry actions" : "Log entry actions",
    "Loading older log entries" : "Loading older log entries",
    "No older log entries available" : "No older log entries available",
    "Collapse row" : "Collapse row",
    "Expand row" : "Expand row",
    "Show details" : "Show details",
    "Debug" : "Debug",
    "Info" : "Info",
    "Warning" : "Warning",
    "Error" : "Error",
    "Fatal" : "Fatal",
    "Could not load log entries" : "Could not load log entries",
    "Clipboard" : "Clipboard",
    "Could not parse clipboard content" : "Could not parse clipboard content",
    "Could not fetch new log entries (server unavailable)" : "Could not fetch new log entries (server unavailable)",
    "Could not fetch new entries" : "Could not fetch new entries",
    "Could not copy to clipboard, please copy manually:" : "Could not copy to clipboard, please copy manually:",
    "\tfrom {address} by {user} at {time}\n" : "\tfrom {address} by {user} at {time}\n",
    "Error parsing log" : "Error parsing log",
    "Caused by " : "Caused by ",
    "Copy" : "Copy",
    "Copy raw" : "Copy raw",
    "Copy formatted" : "Copy formatted",
    "No server logs" : "No server logs",
    "One or more entries are hidden by the log level filter" : "One or more entries are hidden by the log level filter",
    "Everything is working fine" : "Everything is working fine",
    "Load log file" : "Load log file",
    "Invalid log file" : "Invalid log file",
    "Log levels" : "Log levels",
    "Log content" : "Log content",
    "Live update" : "Live update",
    "line {line}" : "line {line}",
    "Download / Upload logs" : "Download / Upload logs"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-28.0.7.tgz: nextcloud/apps/logreader/l10n/en_GB.js <==
OC.L10N.register(
    "logreader",
    {
    "Logging" : "Logging",
    "Errors in the log" : "Errors in the log",
    "Failed to get an iterator for log entries: %s" : "Failed to get an iterator for log entries: %s",
    "No errors in the logs since %s" : "No errors in the logs since %s",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["%n error in the logs since %s","%n errors in the logs since %s"],
    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["%n warning in the logs since %s","%n warnings in the logs since %s"],
    "Log Reader" : "Log Reader",
    "A log reader for Nextcloud" : "A log reader for Nextcloud",
    "Log reader for Nextcloud" : "Log reader for Nextcloud",
    "Log reader" : "Log reader",
    "Open log reader settings" : "Open log reader settings",
    "Log reader settings" : "Log reader settings",
    "Currently the log file {file} is shown" : "Currently the log file {file} is shown",
    "Show server log" : "Show server log",
    "Live view is disabled" : "Live view is disabled",
    "No log file" : "No log file",
    "File-based logging must be enabled to access logs from the Web UI." : "File-based logging must be enabled to access logs from the Web UI.",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual.",
    "Level" : "Level",
    "App" : "App",
    "No app in context" : "No app in context",
    "Time" : "Time",
    "Copy raw entry" : "Copy raw entry",
    "Copy formatted entry" : "Copy formatted entry",
    "Hide exception details" : "Hide exception details",
    "View exception details" : "View exception details",
    "Raw log entry" : "Raw log entry",
    "Log entry successfully copied" : "Log entry successfully copied",
    "Search log entries" : "Search log entries",
    "Caused by {exception}" : "Caused by {exception}",
    "Line {line}" : "Line {line}",
    "Filter log levels" : "Filter log levels",
    "Set log level" : "Set log level",
    "Time format" : "Time format",
    "Live view" : "Live view",
    "Download/Upload logs" : "Download/Upload logs",
    "You can also show log entries copied from your clipboard by pasting them on the log view using: {keyboardShortcut}" : "You can also show log entries copied from your clipboard by pasting them on the log view using: {keyboardShortcut}",
    "Download logs" : "Download logs",
    "Show local log file" : "Show local log file",
    "Upload local log file to be displayed" : "Upload local log file to be displayed",
    "Ctrl" : "Ctrl",
    "Could not parse local log file" : "Could not parse local log file",
    "Raw data" : "Raw data",
    "Local time" : "Local time",
    "UTC time" : "UTC time",
    "Relative" : "Relative",
    "Time format used for displaying the timestamp" : "Time format used for displaying the timestamp",
    "(Local log files only support the \"raw\" time format)" : "(Local log files only support the \"raw\" time format)",
    "Could not change date time format." : "Could not change date time format.",
    "Polling is disabled because server is not configured to log to file" : "Polling is disabled because server is not configured to log to file",
    "Polling (live view)" : "Polling (live view)",
    "Could not change live view setting." : "Could not change live view setting.",
    "Filter logging levels" : "Filter logging levels",
    "Could not set logging levels to show" : "Could not set logging levels to show",
    "Set backend loglevel" : "Set backend loglevel",
    "Could not set logging level" : "Could not set logging level",
    "Application" : "Application",
    "Message" : "Message",
    "Log entry actions" : "Log entry actions",
    "Loading older log entries" : "Loading older log entries",
    "No older log entries available" : "No older log entries available",
    "Collapse row" : "Collapse row",
    "Expand row" : "Expand row",
    "Show details" : "Show details",
    "Debug" : "Debug",
    "Info" : "Info",
    "Warning" : "Warning",
    "Error" : "Error",
    "Fatal" : "Fatal",
    "Could not load log entries" : "Could not load log entries",
    "Clipboard" : "Clipboard",
    "Could not parse clipboard content" : "Could not parse clipboard content",
    "Could not fetch new log entries (server unavailable)" : "Could not fetch new log entries (server unavailable)",
    "Could not fetch new entries" : "Could not fetch new entries",
    "Could not copy to clipboard, please copy manually:" : "Could not copy to clipboard, please copy manually:",
    "\tfrom {address} by {user} at {time}\n" : "\tfrom {address} by {user} at {time}\n",
    "Error parsing log" : "Error parsing log",
    "Caused by " : "Caused by ",
    "Copy" : "Copy",
    "Copy raw" : "Copy raw",
    "Copy formatted" : "Copy formatted",
    "No server logs" : "No server logs",
    "One or more entries are hidden by the log level filter" : "One or more entries are hidden by the log level filter",
    "Everything is working fine" : "Everything is working fine",
    "Load log file" : "Load log file",
    "Invalid log file" : "Invalid log file",
    "Log levels" : "Log levels",
    "Log content" : "Log content",
    "Live update" : "Live update",
    "line {line}" : "line {line}",
    "Download / Upload logs" : "Download / Upload logs"
},
"nplurals=2; plural=(n != 1);");
